@@ -4,6 +4,7 @@
 
 import code
 from functools import partial
+import itertools
 import json
 import logging
 import pprint
@@ -11,6 +12,7 @@ import sys
 import warnings
 
 import click
+from cligj import indent_opt, sequence_opt
 import six.moves
 
 import fiona
@@ -50,8 +52,7 @@ def env(ctx, key):
 @cli.command(short_help="Print information about a dataset.")
 # One or more files.
 @click.argument('input', type=click.Path(exists=True))
-@click.option('--indent', default=None, type=int, 
-              help="Indentation level for pretty printed output.")
+@indent_opt
 # Options to pick out a single metadata item and print it as
 # a string.
 @click.option('--count', 'meta_member', flag_value='count',
@@ -61,13 +62,12 @@ def env(ctx, key):
 @click.option('--crs', 'meta_member', flag_value='crs',
               help="Print the CRS as a PROJ.4 string.")
 @click.option('--bounds', 'meta_member', flag_value='bounds',
-              help="Print the nodata value.")
+              help="Print the boundary coordinates "
+                   "(left, bottom, right, top).")
 @click.pass_context
 def info(ctx, input, indent, meta_member):
-    verbosity = ctx.obj['verbosity']
+    verbosity = (ctx.obj and ctx.obj['verbosity']) or 2
     logger = logging.getLogger('rio')
-
-    stdout = click.get_text_stream('stdout')
     try:
         with fiona.drivers(CPL_DEBUG=verbosity>2):
             with fiona.open(input) as src:
@@ -79,12 +79,11 @@ def info(ctx, input, indent, meta_member):
                 info['crs'] = proj4
                 if meta_member:
                     if isinstance(info[meta_member], (list, tuple)):
-                        print(" ".join(map(str, info[meta_member])))
+                        click.echo(" ".join(map(str, info[meta_member])))
                     else:
-                        print(info[meta_member])
+                        click.echo(info[meta_member])
                 else:
-                    stdout.write(json.dumps(info, indent=indent))
-                    stdout.write("\n")
+                    click.echo(json.dumps(info, indent=indent))
         sys.exit(0)
     except Exception:
         logger.exception("Failed. Exception caught")
@@ -95,7 +94,7 @@ def info(ctx, input, indent, meta_member):
 @click.argument('src_path', type=click.Path(exists=True))
 @click.pass_context
 def insp(ctx, src_path):
-    verbosity = ctx.obj['verbosity']
+    verbosity = (ctx.obj and ctx.obj['verbosity']) or 2
     logger = logging.getLogger('fio')
     try:
         with fiona.drivers(CPL_DEBUG=verbosity>2):
@@ -120,16 +119,15 @@ def insp(ctx, src_path):
               help="Output format driver name.")
 @click.option('--src_crs', default=None, help="Source CRS.")
 @click.option('--dst_crs', default=None, help="Destination CRS.")
-@click.option('--x-json-seq/--x-json-obj', default=False,
-              help="Read a LF-delimited JSON sequence (default is object). Experimental.")
+@sequence_opt
 @click.pass_context
 
-def load(ctx, output, driver, src_crs, dst_crs, x_json_seq):
+def load(ctx, output, driver, src_crs, dst_crs, sequence):
     """Load features from JSON to a file in another format.
 
     The input is a GeoJSON feature collection or optionally a sequence of
     GeoJSON feature objects."""
-    verbosity = ctx.obj['verbosity']
+    verbosity = (ctx.obj and ctx.obj['verbosity']) or 2
     logger = logging.getLogger('fio')
     stdin = click.get_text_stream('stdin')
 
@@ -158,7 +156,7 @@ def load(ctx, output, driver, src_crs, dst_crs, x_json_seq):
                 feat = json.loads(buffer)
                 feat['geometry'] = transformer(feat['geometry'])
                 yield feat
-    elif x_json_seq:
+    elif sequence:
         def feature_gen():
             yield json.loads(first_line)
             for line in stdin:
@@ -167,7 +165,8 @@ def load(ctx, output, driver, src_crs, dst_crs, x_json_seq):
                 yield feat
     else:
         def feature_gen():
-            for feat in json.load(input)['features']:
+            text = "".join(itertools.chain([first_line], stdin))
+            for feat in json.loads(text)['features']:
                 feat['geometry'] = transformer(feat['geometry'])
                 yield feat
 
@@ -179,7 +178,7 @@ def load(ctx, output, driver, src_crs, dst_crs, x_json_seq):
         first = next(source)
         schema = {'geometry': first['geometry']['type']}
         schema['properties'] = dict([
-            (k, FIELD_TYPES_MAP_REV[type(v)])
+            (k, FIELD_TYPES_MAP_REV.get(type(v)) or 'str')
             for k, v in first['properties'].items()])
 
         with fiona.drivers(CPL_DEBUG=verbosity>2):
